changeset 20147:09c103c821b1 draft

(svn r25091) -Codechange: Call keycodes by their name.
author frosch <frosch@openttd.org>
date Sun, 17 Mar 2013 13:05:18 +0000
parents b39f0ea0d0cc
children 115d14632c22
files src/textbuf.cpp src/textbuf_type.h
diffstat 2 files changed, 14 insertions(+), 12 deletions(-) [+]
line wrap: on
line diff
--- a/src/textbuf_type.h
+++ b/src/textbuf_type.h
@@ -36,10 +36,12 @@
 	void CDECL Print(const char *format, ...) WARN_FORMAT(2, 3);
 
 	void DeleteAll();
-	bool DeleteChar(int delmode);
+	bool InsertClipboard();
+
 	bool InsertChar(uint32 key);
-	bool InsertClipboard();
-	bool MovePos(int navmode);
+
+	bool DeleteChar(uint16 keycode);
+	bool MovePos(uint16 keycode);
 
 	bool HandleCaret();
 	void UpdateSize();
--- a/src/textbuf.cpp
+++ b/src/textbuf.cpp
@@ -98,13 +98,13 @@
 /**
  * Delete a character from a textbuffer, either with 'Delete' or 'Backspace'
  * The character is delete from the position the caret is at
  * @param delmode Type of deletion, either WKC_BACKSPACE or WKC_DELETE
  * @return Return true on successful change of Textbuf, or false otherwise
  */
-bool Textbuf::DeleteChar(int delmode)
+bool Textbuf::DeleteChar(uint16 keycode)
 {
-	if (delmode == WKC_BACKSPACE || delmode == WKC_DELETE) {
-		bool backspace = delmode == WKC_BACKSPACE;
+	if (keycode == WKC_BACKSPACE || keycode == WKC_DELETE) {
+		bool backspace = keycode == WKC_BACKSPACE;
 		if (CanDelChar(backspace)) {
 			this->DelChar(backspace);
 			return true;
@@ -112,8 +112,8 @@
 		return false;
 	}
 
-	if (delmode == (WKC_CTRL | WKC_BACKSPACE) || delmode == (WKC_CTRL | WKC_DELETE)) {
-		bool backspace = delmode == (WKC_CTRL | WKC_BACKSPACE);
+	if (keycode == (WKC_CTRL | WKC_BACKSPACE) || keycode == (WKC_CTRL | WKC_DELETE)) {
+		bool backspace = keycode == (WKC_CTRL | WKC_BACKSPACE);
 
 		if (!CanDelChar(backspace)) return false;
 		WChar c = this->GetNextDelChar(backspace);
@@ -276,12 +276,12 @@
 /**
  * Handle text navigation with arrow keys left/right.
  * This defines where the caret will blink and the next character interaction will occur
  * @param navmode Direction in which navigation occurs (WKC_CTRL |) WKC_LEFT, (WKC_CTRL |) WKC_RIGHT, WKC_END, WKC_HOME
  * @return Return true on successful change of Textbuf, or false otherwise
  */
-bool Textbuf::MovePos(int navmode)
+bool Textbuf::MovePos(uint16 keycode)
 {
-	switch (navmode) {
+	switch (keycode) {
 		case WKC_LEFT:
 			if (this->CanMoveCaretLeft()) {
 				this->MoveCaretLeft();
@@ -98,13 +98,13 @@
  * Delete a character from a textbuffer, either with 'Delete' or 'Backspace'
  * The character is delete from the position the caret is at
- * @param delmode Type of deletion, either WKC_BACKSPACE or WKC_DELETE
+ * @param keycode Type of deletion, either WKC_BACKSPACE or WKC_DELETE
  * @return Return true on successful change of Textbuf, or false otherwise
  */
@@ -276,12 +276,12 @@
  * Handle text navigation with arrow keys left/right.
  * This defines where the caret will blink and the next character interaction will occur
- * @param navmode Direction in which navigation occurs (WKC_CTRL |) WKC_LEFT, (WKC_CTRL |) WKC_RIGHT, WKC_END, WKC_HOME
+ * @param keycode Direction in which navigation occurs (WKC_CTRL |) WKC_LEFT, (WKC_CTRL |) WKC_RIGHT, WKC_END, WKC_HOME
  * @return Return true on successful change of Textbuf, or false otherwise
  */